@@ -188,7 +188,7 @@ sub run {
                     next if /^\s*$/;
                     # Skip common "lead-in" lines
                     $description .= $_
-                      unless m{^(?:Index: |=+$|diff .+|index )};
+                      unless m{^(?:Index: |=+$|diff .+|index |From: )};
                     $has_template_description = 1
                       if index($_, PATCH_DESC_TEMPLATE) != -1;
                 }
@@ -241,6 +241,9 @@ sub run {
                 $known_files{$1}++ if m{^\s*(?:#+\s*)?(\S+)};
             }
             close($fd);
+
+            tag 'package-uses-vendor-specific-patch-series', $file
+              if $file =~ /\.series$/;
         }
 
         foreach my $file ($dpdir->children('breadth-first')) {
